@@ -3,18 +3,14 @@ use std::path;
 
 use anyhow::Context as _;
 
-use crate::error::*;
+use crate::error::Result;
 
 #[derive(Clone, Debug, PartialEq, Eq, clap::Args)]
-pub struct ConfigArgs {
+pub(crate) struct ConfigArgs {
     /// Config file to use [default: _cobalt.yml]
     #[arg(short, long, value_name = "FILE")]
     config: Option<path::PathBuf>,
 
-    /// Site destination folder [default: ./]
-    #[arg(short, long, value_name = "DIR")]
-    destination: Option<path::PathBuf>,
-
     /// Include drafts.
     #[arg(long)]
     drafts: bool,
@@ -25,7 +21,7 @@ pub struct ConfigArgs {
 }
 
 impl ConfigArgs {
-    pub fn load_config(&self) -> Result<cobalt_config::Config> {
+    pub(crate) fn load_config(&self) -> Result<cobalt_config::Config> {
         let config_path = self.config.as_deref();
 
         // Fetch config information if available
@@ -37,15 +33,6 @@ impl ConfigArgs {
             cobalt_config::Config::from_cwd(".")?
         };
 
-        config.abs_dest = self
-            .destination
-            .as_deref()
-            .map(|d| {
-                std::fs::create_dir_all(d)?;
-                dunce::canonicalize(d)
-            })
-            .transpose()?;
-
         if let Some(drafts) = self.drafts() {
             config.include_drafts = drafts;
         }
@@ -53,7 +40,7 @@ impl ConfigArgs {
         Ok(config)
     }
 
-    pub fn drafts(&self) -> Option<bool> {
+    pub(crate) fn drafts(&self) -> Option<bool> {
         resolve_bool_arg(self.drafts, self.no_drafts)
     }
 }
@@ -67,7 +54,7 @@ fn resolve_bool_arg(yes: bool, no: bool) -> Option<bool> {
     }
 }
 
-pub fn init_logging(
+pub(crate) fn init_logging(
     level: clap_verbosity_flag::Verbosity<clap_verbosity_flag::InfoLevel>,
     colored: bool,
 ) {
@@ -132,7 +119,7 @@ struct Palette {
 }
 
 impl Palette {
-    pub fn colored() -> Self {
+    pub(crate) fn colored() -> Self {
         Self {
             error: yansi::Style::new(yansi::Color::Red).bold(),
             warn: yansi::Style::new(yansi::Color::Yellow),
@@ -141,7 +128,7 @@ impl Palette {
         }
     }
 
-    pub fn plain() -> Self {
+    pub(crate) fn plain() -> Self {
         Self {
             error: yansi::Style::default(),
             warn: yansi::Style::default(),
