@@ -9,33 +9,33 @@ use notify::Watcher as _;
 
 use crate::args;
 use crate::build;
-use crate::error::*;
+use crate::error::Result;
 
 /// Build, serve, and watch the project at the source dir
 #[derive(Clone, Debug, PartialEq, Eq, clap::Args)]
-pub struct ServeArgs {
+pub(crate) struct ServeArgs {
     /// Open a browser
     #[arg(long)]
-    pub open: bool,
+    pub(crate) open: bool,
 
     /// Host to serve from
     #[arg(long, value_name = "HOSTNAME_OR_IP", default_value = "localhost")]
-    pub host: String,
+    pub(crate) host: String,
 
     /// Port to serve from
     #[arg(short = 'P', long, value_name = "NUM")]
-    pub port: Option<u16>,
+    pub(crate) port: Option<u16>,
 
     /// Disable rebuilding on change
     #[arg(long)]
-    pub no_watch: bool,
+    pub(crate) no_watch: bool,
 
     #[command(flatten, next_help_heading = "Config")]
-    pub config: args::ConfigArgs,
+    pub(crate) config: args::ConfigArgs,
 }
 
 impl ServeArgs {
-    pub fn run(&self) -> Result<()> {
+    pub(crate) fn run(&self) -> Result<()> {
         let dest = tempfile::tempdir()?;
 
         let mut server = file_serve::ServerBuilder::new(dest.path());
@@ -48,7 +48,7 @@ impl ServeArgs {
         let mut config = self.config.load_config()?;
         debug!("Overriding config `site.base_url` with `/`");
         config.site.base_url = Some("/".into());
-        let mut config = cobalt::cobalt_model::Config::from_config(config)?;
+        let mut config = cobalt_model::Config::from_config(config)?;
         debug!(
             "Overriding config `destination` with `{}`",
             dest.path().display()
