@@ -1,6 +1,5 @@
 use std::ffi;
 use std::fs;
-use std::io::Read;
 use std::io::Write;
 use std::path;
 
@@ -263,9 +262,7 @@ pub fn cleanup_path(path: &str) -> String {
 }
 
 pub fn read_file<P: AsRef<path::Path>>(path: P) -> Result<String> {
-    let mut file = fs::File::open(path.as_ref())?;
-    let mut text = String::new();
-    file.read_to_string(&mut text)?;
+    let text = fs::read_to_string(path.as_ref())?;
     let text: String = normalized(text.chars()).collect();
     Ok(text)
 }
